import { ProFormColumnsType } from "@ant-design/pro-components";

function formConfig(props: { paragraphList?: any[], enumList?: { [key: string]: any }, paymentType: any }): ProFormColumnsType<{
    name: string;
    state: string;
}>[] {
    let { paragraphList, enumList, paymentType } = props
    console.log(paymentType)
    return [
        {
            title: '付费方式',
            dataIndex: 'paymentType',
            valueType: 'radio',
            fieldProps: {
                onChange: (e) => {
                    let value = e.target.value
                    paymentType[1](value)
                }
            },
            formItemProps: {
                style: { marginBottom: 0 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            valueEnum: () => {
                let arr = enumList?.PAYMENT_TYPE?.values
                return new Map(arr?.map(({ value, description }: any) => [value, description]))
            }
        },
        {
            title: '收费类型',
            dataIndex: 'paymentOption',
            valueType: 'radio',
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            hideInForm:paymentType[0] != 2,
            valueEnum: () => {
                let arr = enumList?.PAYMENT_OPTION?.values
                return new Map(arr?.map(({ value, description }: any) => [value, description]))
            }
        },
        {
            title: '开始付费段落',
            dataIndex: 'beginPayParagraphNo',
            valueType: 'select',
            fieldProps: {
                showSearch: true, placeholder: '请选择开始收费段落'
            },
            formItemProps: {
                style: { marginBottom: 15 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            hideInForm:paymentType[0] != 2,
            valueEnum: () => {
                return new Map(paragraphList?.map(item => [item.paragraphNo, item.content]))
            }
        },
        {
            title: 'VIP阅读',
            dataIndex: 'vipFree',
            valueType: 'segmented',
            formItemProps: {
                style: { marginBottom: 15 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            hideInForm:paymentType[0] == 0,
            valueEnum: () => {
                let arr = enumList?.VIP_FREE?.values
                return new Map(arr?.map(({ value, description }: any) => [value, description]))
            }
        },
        {
            title: '收费金额',
            dataIndex: 'paymentAmount',
            valueType: 'money',
            hideInForm: paymentType[0] != 1,
            formItemProps: {
                style: { marginBottom: 15 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
        },
        {
            title: '收费书币',
            dataIndex: 'paymentCoin',
            valueType: 'digit',
            hideInForm: paymentType[0] != 2,
            formItemProps: {
                style: { marginBottom: 15 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
        },
        {
            title: '备注',
            dataIndex: 'remark',
            valueType: 'textarea',
            formItemProps: {
                style: { marginBottom: 15 },
            },
        }
    ]
}

export default formConfig